KnownUsbPrinter class

Constructors

KnownUsbPrinter({required int vid, required int pid, required String displayName, String protocol = 'escpos', bool exactModel = true})
const

Properties

displayName String
final
exactModel bool
final
hashCode int
The hash code for this object.
no setterinherited
pid int
final
protocol String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vid int
final

Methods

matches(int queryVid, int queryPid) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited