MethodChannelTiPrinterPlugin class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeSerialPort() Future<bool>
override
closeUsbPort() Future<bool>
override
disableAsb() Future<bool>
override
enableAsb() Future<bool>
override
flushUsbBuffer() Future<bool>
override
getPlatformVersion() Future<String>
override
getUsbPrinters() Future<List<PrinterDeviceInfo>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSerialPort(String portName, int baudRate) Future<bool>
override
openUsbPort(String deviceInstanceId) Future<bool>
override
readFromUsb() Future<Uint8List>
override
readStatusSerial(Uint8List command) Future<Uint8List>
override
readStatusUsb(Uint8List command) Future<Uint8List>
override
readStatusUsbDetailed(Uint8List command) Future<UsbStatusReadResult>
override
sendAndReadStatusUsb(Uint8List command) Future<Uint8List>
override
sendCommandToSerial(Uint8List command) Future<bool>
override
sendCommandToUsb(Uint8List command) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited