TiPrinterPluginPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- TiPrinterPluginPlatform
- Implementers
Constructors
- TiPrinterPluginPlatform()
- Constructs a TiPrinterPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeSerialPort(
) → Future< bool> -
closeUsbPort(
) → Future< bool> -
getPlatformVersion(
) → Future< String> -
getUsbPrinters(
) → Future< List< PrinterDeviceInfo> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openSerialPort(
String portName, int baudRate) → Future< bool> -
openUsbPort(
String deviceInstanceId) → Future< bool> -
readStatusSerial(
Uint8List command) → Future< Uint8List> -
readStatusUsb(
Uint8List command) → Future< Uint8List> -
sendCommandToSerial(
Uint8List command) → Future< bool> -
sendCommandToUsb(
Uint8List command) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ TiPrinterPluginPlatform
-
The default instance of TiPrinterPluginPlatform to use.
getter/setter pair