UsbStatusReadResult class

Constructors

UsbStatusReadResult({required UsbStatusReadKind kind, required Uint8List data})
const
UsbStatusReadResult.fromMap(Map map)
factory

Properties

data Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
kind UsbStatusReadKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited