PrinterDeviceInfo class
Constructors
- PrinterDeviceInfo({required String instanceId, required String displayName, required int vid, required int pid})
-
const
-
PrinterDeviceInfo.fromMap(Map<
String, dynamic> map) -
factory
Properties
- displayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- instanceId → String
-
final
- pid → int
-
final
- resolvedDisplayName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vid → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override